```
Usage: vcd gateway services crl-certificate add [OPTIONS] <gateway name>

Options:
  --certificate-path <>  certificate file path  [required]
  --description <>       description
  -h, --help             Show this message and exit.

```
